projectal.entities.webhook API documentation

# projectal.entities.webhook

View Source

    from projectal import api
    from projectal.entity import Entity

    class Webhook(Entity):
        """
        Implementation of the [Webhook](https://projectal.com/docs/latest/#tag/Webhook) API.
        """
        _path = 'webhook'
        _name = 'WEBHOOK'

        @classmethod
        def list(cls, start=0, limit=101, ksort='entity', order='asc'):
            """
            Get a list of registered webhooks.

            Optionally specify a range for pagination.
            """
            url = '/api/webhook/list?start={}&limit={}&ksort={}&order={}'.\
                      format(start, limit, ksort, order)
            return api.get(url)

class Webhook(projectal.entity.Entity):
View Source

    class Webhook(Entity):
        """
        Implementation of the [Webhook](https://projectal.com/docs/latest/#tag/Webhook) API.
        """
        _path = 'webhook'
        _name = 'WEBHOOK'

        @classmethod
        def list(cls, start=0, limit=101, ksort='entity', order='asc'):
            """
            Get a list of registered webhooks.

            Optionally specify a range for pagination.
            """
            url = '/api/webhook/list?start={}&limit={}&ksort={}&order={}'.\
                      format(start, limit, ksort, order)
            return api.get(url)

Implementation of the Webhook API.

@classmethod
def list(cls, start=0, limit=101, ksort='entity', order='asc'):
View Source

        @classmethod
        def list(cls, start=0, limit=101, ksort='entity', order='asc'):
            """
            Get a list of registered webhooks.

            Optionally specify a range for pagination.
            """
            url = '/api/webhook/list?start={}&limit={}&ksort={}&order={}'.\
                      format(start, limit, ksort, order)
            return api.get(url)

Get a list of registered webhooks.

Optionally specify a range for pagination.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  create
  save
  clone
  history
  match
  match_startswith
  match_endswith
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy